@@ -229,10 +229,10 @@ about_me_focus_out (GtkWidget *widget, GdkEventFocus *event, GnomeAboutMe *me)
 		iter_end = iter_start;
 		gtk_text_iter_forward_to_end (&iter_end);
 		str = gtk_text_iter_get_text (&iter_start, &iter_end);
+	} else {
+		str = "";
 	}
 
-	str = str ? str : "";
-	
 	/* FIXME: i'm getting an empty address field in evolution */
 	if (i >= ADDRESS_HOME && i < ADDRESS_WORK) {
 		about_me_set_address_field (me->addr1, ids[i].cid, str);
@@ -273,10 +273,11 @@ get_user_login (void)
 static gchar *
 about_me_get_address_field (EContactAddress *addr, guint cid)
 {
-	gchar *str = NULL;
+	gchar *str;
 	
-	if (addr == NULL)
+	if (addr == NULL) {
 		return NULL;
+	}
 
 	switch (cid) {
 		case ADDRESS_STREET:
@@ -297,6 +298,9 @@ about_me_get_address_field (EContactAddress *addr, guint cid)
 		case ADDRESS_COUNTRY:
 			str = addr->country;
 			break;
+		default:
+			str = NULL;
+			break;
 	}
 
 	return str;
@@ -549,9 +553,9 @@ about_me_image_clicked_cb (GtkWidget *button, GnomeAboutMe *me)
 
 	chooser_dialog = gtk_file_chooser_dialog_new (_("Select Image"), GTK_WINDOW (WID ("about-me-dialog")),
 							GTK_FILE_CHOOSER_ACTION_OPEN,
+							_("No Image"), GTK_RESPONSE_NO,
 							GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 							GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
-							_("No Image"), GTK_RESPONSE_NO,
 							NULL);
 	gtk_window_set_modal (GTK_WINDOW (chooser_dialog), TRUE);
 	gtk_dialog_set_default_response (GTK_DIALOG (chooser_dialog), GTK_RESPONSE_ACCEPT);
@@ -648,7 +652,7 @@ about_me_passwd_clicked_cb (GtkWidget *button, GnomeAboutMe *me)
 	gnome_about_me_password (GTK_WINDOW (WID ("about-me-dialog")));
 }
 
-static void
+static gint
 about_me_setup_dialog (void)
 {
 	GtkWidget    *widget;
@@ -666,6 +670,11 @@ about_me_setup_dialog (void)
 	dialog = glade_xml_new (GNOMECC_DATA_DIR "/interfaces/gnome-about-me.glade", 
 				"about-me-dialog", NULL);
 
+	if (dialog == NULL) {
+		g_error ("Unable to load glade file.");
+		exit (1);
+	}
+
 	me->dialog = dialog;
 
 	/* Connect the close button signal */
@@ -693,21 +702,30 @@ about_me_setup_dialog (void)
 
 	/* Get the self contact */
 	if (!e_book_get_self (&me->contact, &me->book, &error)) {
+		if (error->code == E_BOOK_ERROR_PROTOCOL_NOT_SUPPORTED) {
+			about_me_error (NULL, _("There was an error while trying to get the addressbook information\n" \
+						"Evolution Data Server can't handle the protocol"));
+			return -1;
+		}	
+
 		me->create_self = TRUE;
 		
 		me->contact = e_contact_new ();
-		g_print ("%s\n", error->message);
 
+		g_warning ("%s\n", error->message);
 		g_clear_error (&error);
 
 		if (me->book == NULL) {
 			me->book = e_book_new_system_addressbook (&error);
-			if (me->book == NULL)
-				g_print ("error message: %s\n", error->message);
+			if (me->book == NULL || error != NULL) {
+				g_error ("%s\n", error->message);
+				g_clear_error (&error);
+			}
 
 			if (e_book_open (me->book, FALSE, NULL) == FALSE) {
 				about_me_error (GTK_WINDOW (main_dialog), 
 						_("Unable to open address book"));
+				g_clear_error (&error);
 			}
 		} 
 	}
@@ -719,7 +737,7 @@ about_me_setup_dialog (void)
 	if (pwent == NULL) {
 		about_me_error (GTK_WINDOW (WID ("about-me-dialog")), 
 				_("Unknown login ID, the user database might be corrupted"));
-		return ;
+		return -1;
 	}
 	gchar **tok;
 	tok = g_strsplit (pwent->pw_gecos, ",", 0);
@@ -771,6 +789,8 @@ about_me_setup_dialog (void)
 	about_me_load_info (me);
 
 	gtk_widget_show_all (main_dialog);
+
+	return 0;
 }
 
 int
@@ -785,8 +805,11 @@ main (int argc, char **argv)
 		GNOME_PARAM_APP_DATADIR, GNOMECC_DATA_DIR,
 		NULL);
 
-	about_me_setup_dialog ();
-	gtk_main ();
+	if (about_me_setup_dialog () == -1) {
+		return -1;
+	} else {
+		gtk_main ();
+	}
 
 	return 0;
 }
