@@ -128,7 +128,14 @@ static gboolean
 delay_value_changed_cb (GtkWidget *range, GtkScrollType scroll, gdouble value,
 			gpointer   dialog)
 {
-	gchar *message = g_strdup_printf ("%.1f %s", value / 1000.0, _("seconds"));
+	gchar *message;
+
+	if (value < 100)
+		value = 100;
+	else if (value > 1000)
+		value = 1000;
+
+	message = g_strdup_printf ("%.1f %s", value / 1000.0, _("seconds"));
 	gtk_label_set_label ((GtkLabel*) WID ("delay_label"), message);
 	g_free (message);
 
@@ -587,8 +594,8 @@ cursor_changed (GtkTreeSelection *selection,
 #else
 		gconf_client_set_string (client,
 					 CURSOR_FONT_KEY, cursor_font, NULL);
-		g_free (cursor_font);
 #endif
+		g_free (cursor_font);
 	} else {
 #ifdef HAVE_XCURSOR
 		gconf_client_unset (client,
@@ -648,14 +655,18 @@ static void
 populate_tree_model(GtkTreeModelSort* model, GtkTreeSelection* selection) {
 #ifdef HAVE_XCURSOR
 	// add the XCursor themes - paths taken from <xc/lib/Xcursor.library.c>
-	const gchar* const paths[] = {
+	const gchar* const path_defs[] = {
 		"%s/.icons/",
 		"/usr/share/icons/",
 		"/usr/share/pixmaps/",
 		"/usr/X11R6/lib/X11/icons/",
 		NULL
 	};
-	const gchar* const * iterator;
+	const gchar *xpaths = g_getenv ("XCURSOR_PATH");
+
+	gchar **iterator = NULL;
+	gchar **paths = NULL;
+
 	GConfClient* client = gconf_client_get_default();
 	GtkListStore* store = GTK_LIST_STORE(gtk_tree_model_sort_get_model(model));
 	gchar* current_theme = gconf_client_get_string(client, CURSOR_THEME_KEY, NULL);
@@ -663,6 +674,12 @@ populate_tree_model(GtkTreeModelSort* model, GtkTreeSelection* selection) {
 	g_object_unref(client);
 	client = NULL;
 
+	if (xpaths != NULL) {
+		paths = g_strsplit (xpaths, ":", 0);
+	} else {
+		paths = g_strdupv ((gchar **) path_defs);
+	}
+
 	for(iterator = paths; *iterator; iterator++) {
 		gchar*       fname = NULL;
 		GDir*        folder = NULL;
@@ -677,7 +694,7 @@ populate_tree_model(GtkTreeModelSort* model, GtkTreeSelection* selection) {
 		folder = g_dir_open(fname, 0, NULL);
 		
 		while(folder && (name = g_dir_read_name(folder))) {
-			gchar* cursor_dir = g_strdup_printf("%s%s/cursors/", fname, name);
+			gchar* cursor_dir = g_strdup_printf("%s/%s/cursors/", fname, name);
 			XcursorImage* cursor;
 			gint sizes[] = { 12, 16, 24, 32, 36, 48, 0 };
 			gint i;
@@ -690,7 +707,7 @@ populate_tree_model(GtkTreeModelSort* model, GtkTreeSelection* selection) {
 			
 			for (i = 0; sizes[i] != 0; i++) {
 				cursor = XcursorLibraryLoadImage("left_ptr", name, sizes[i]);
-				if (cursor->size != sizes[i]) {
+				if (cursor && cursor->size != sizes[i]) {
 					XcursorImageDestroy (cursor);
 					cursor = NULL;
 				}
@@ -731,6 +748,10 @@ populate_tree_model(GtkTreeModelSort* model, GtkTreeSelection* selection) {
 	}
 	
 	g_free(current_theme);
+
+	if (xpaths != NULL) {
+		g_strfreev (paths);
+	}
 #else /* !HAVE_XCURSOR */
 	gchar* cursor_font;
 	static const gchar* builtins[][5] = {
